/*
 * File: bugs.sql
 *
 * Description:
 *    This file contains all the table definitions for the bug tracking stuff
 * in order for the entire bug system to work it requires the use of member
 * tables, project tables and task manager tables.
 *
 * Creator: Chris Ryan <chris@greatbridge.com>
 * Created: 10/05/2000
 *
 * Change Log:
 *     Chris Ryan <chris@greatbridge.com> 10/05/2000
 *         - Initial File creation
 *     Allen McGrath <amcgrath@greatbridge.com> 10/12/2000
 *         - Added the TITLE column to the BUG table, for a short
 *           description, mainly for display.
 *     Chris Ryan <chris@greatbridge.com> 10/25/2000
 *         - Added additional comments to tables
 *     Chris Ryan <chris@greatbridge.com> 10/27/2000
 *         - Added new field environment to bug table
 */

/*
 * Table: bug
 *
 * Description: A report of a bug
 *
 * Field Description:
 * bug_id          the id of this bug (primary key)
 * project_id      the project_id to the project this bug is part of
 * class_id        the class of bug
 * priority        a number representing the priority of this bug
 * severity_id     the severity of this bug
 * status_id       the status of this bug
 * title           a short title of this bug (a.k.a. brief description)
 * description     a full description of this bug
 * version         the version of the software
 * os              the os the software is running on
 * os_version      the version of the os the software is running on
 * platform        the platform the software is running on (Intel, Web, etc.)
 * task_id         the task this bug is assigned to
 * created_by      the id of the member who created the bug
 * email           the email of the person who created this bug
 * date_created    the date this bug was created
 *
 * Notes: This created_by field is used if the person creating the bug
 *        is a member of the site otherwise the email must be filled so
 *        we always have some way of identifing people who created bugs.
 */
CREATE SEQUENCE bug_bug_id_seq;
CREATE TABLE bug (
    bug_id         int4 not null unique default nextval('bug_bug_id_seq'),
    project_id     int4 not null references project (project_id),
    class_id       int4 not null references category (cat_id),
    priority       int4 not null,
    severity_id    int4 not null references category (cat_id),
    status_id      int4 not null references category (cat_id),    
    title          varchar(100),
    environment    text not null,
    description    text not null,
    version        varchar(32) not null,
    os             varchar(32) not null,
    os_version     varchar(32) not null,
    platform       varchar(32) not null,
    task_id        int4,
    created_by     int4,
    email          varchar(128),
    date_created   timestamp not null default now(),
    primary key(bug_id)
);

/*
 * Table: bug_comment
 *
 * Description: Comments on a bug. Relates to a bug.
 *
 * Field Description:
 * comment_id      the id of this comment (primary key)
 * bug_id          the id of the bug this comment references
 * comment         the comment
 * created_by      the member of the site who created this comment
 * email           the email of the person who created this comment
 * date_created    the date this comment was created
 *
 * Notes: created_by is filled if the person creating the comment is a
 *        member otherwise email must be filled in so we can at least
 *        keep track of poeple adding comments without forcing them to
 *        be members of the site.
 */
CREATE SEQUENCE bug_comment_id_seq;
CREATE TABLE bug_comment (
    comment_id     int4 not null unique default nextval('bug_comment_id_seq'),
    bug_id         int4 not null references bug (bug_id),
    comment        text not null,
    created_by     int4,
    email          varchar(128),
    date_created   timestamp not null default now(),
    primary key(comment_id)
);

