/*
 * File: patch.sql
 *
 * Description:
 *     These are the tables used by the patch manager.
 *
 * Creator: Chris Ryan <chris@greatbridge.com>
 * Created: 10/03/2000
 *
 * Change Log:
 *     Chris Ryan <chris@Greatbridge.com> 10/03/2000
 *         - Initial file creation
 *     Chris Ryan <chris@greatbridge.com> 10/25/2000
 *         - Added additional comments
 */

/*
 * Table: patch
 *
 * Description: Contains the patch information
 *
 * Field Description:
 * patch_id       the id of this patch (primary key)
 * patch_name     the name of the patch
 * description    a description about the patch
 * version        the version this patch applies to
 * file_path      the path to the file
 * url            the url to this patch
 * project_id     the id of the project this patch is part of
 * status_id      the status of this patch
 * category_id    the category this patch is in (Bug fix, Enhancement, etc.)
 * assigned_to    the person who this patch is responsible for
 * created_by     the person who created this patch entry
 * date_created   the date this patch was created
 */
CREATE SEQUENCE patch_patch_id_seq;
CREATE TABLE patch (
    patch_id      int4 not null unique default nextval('patch_patch_id_seq'),
    patch_name    varchar(32) not null,
    description   text,
    version       varchar(32),
    file_path     varchar(256),
    url           varchar(256),
    project_id    int4 not null references project (project_id),
    status_id     int4 not null references category (cat_id),
    category_id   int4 not null references category (cat_id),
    assigned_to   int4,
    created_by    int4 not null references member (member_id),
    date_created  timestamp not null default now(),
    primary key(patch_id)
);

/*
 * Table: patch_history
 *
 * Description: A history of pathces and changes to them.
 *
 * Field Description
 * history_id     the id of this history record (primary key)
 * patch_id       the id of the patch this history is part of
 * description    a description of the history
 * created_by     the member who made a change to have this history
 * date_created   the date this history record was created
 */
CREATE SEQUENCE patch_history_id_seq;
CREATE TABLE patch_history (
    history_id    int4 not null unique default nextval('patch_history_id_seq'),
    patch_id      int4 not null references patch (patch_id),
    description   text,
    created_by    int4 not null references member (member_id),
    date_created  timestamp not null default now(),
    primary key(history_id)
);

/*
 * Table: patch_comment
 *
 * Description: comments attached to patches
 *
 * Field Description:
 * comment_id     the id of this patch comment (primary key)
 * patch_id       the id of the patch this comment belongs to
 * comment        the comment
 * created_by     the member who created this comment
 * date_created   the date this comment was created
 */
CREATE SEQUENCE patch_comment_id_seq;
CREATE TABLE patch_comment (
    comment_id    int4 not null unique default nextval('patch_comment_id_seq'),
    patch_id      int4 not null references patch (patch_id),
    comment       text not null,
    created_by    int4 not null references member (member_id),
    date_created  timestamp not null default now(),
    primary key(comment_id)
);

