/*
 * File: project.sql
 *
 * Description:
 * This file contains all the project tables
 *
 * Creator: Chris Ryan <chris@greatbridge.com>
 * Created: 09/25/2000
 *
 * Change log:
 *     Chris Ryan <chris@greatbridge.com> 09/25/2000
 *         - Initial file creation
 *     Chris Ryan <chris@greatbridge.com> 09/27/2000
 *         - Added date_created to project
 *         - Added site_group_id to project
 *     Chris Ryan <chris@greatbridge.com> 10/25/2000
 *         - Moved project_category from project_category.sql
 *           into this file and added comments for it
 *         - Moved project_join from project_join.sql into
 *           this file and added comments for it
 *         - Moved project_news from project_news.sql into
 *           this file and added comments for it
 *     Chris Ryan <chris@greatbridge.com> 11/13/2000
 *         - Added the project_version table
 *         - Added the project_errata table
 *     Chris Ryan <chris@greatbridge.com> 01/02/2001
 *         - Added the field on_homepage to project_news table
 */

/*
 * Table: license
 *
 * Description:
 *     A table of all available licenses available for people to use on
 * projects
 *
 * Field Description:
 * license_id    the id of this license
 * license_name  the name of this license
 * license_url   a link to where this license can be found
 * description   a short description of this license
 * approved      whether this license is approved or not by GB
 */
CREATE SEQUENCE license_license_id_seq;
CREATE TABLE license (
    license_id   int4 not null unique default nextval('license_license_id_seq'),
    license_name varchar(64) not null unique,
    license_url  varchar(500),
    description  text,
    approved     boolean default false,
    primary key(license_id)
);

/*
 * Table: stage
 *
 * Description:
 *     This table contains the different stages a project can be in
 *
 * Field Description:
 * stage_id       the id number of this stage
 * stage_name     the name of this stage
 * description    the description of this stage
 */
CREATE SEQUENCE stage_stage_id_seq;
CREATE TABLE stage (
    stage_id      int4 not null unique default nextval('stage_stage_id_seq'),
    stage_name    varchar(20) not null unique,
    description   text,
    primary key(stage_id)
);

/*
 * Table: project
 *
 * Description:
 *     The project table contains all the projects. This probably isn't the
 * correct file for it but some of the tables reference it here. This will
 * be fixed when we start the actual projects. For now it is a table with
 * project_id for the references.
 *
 * Field Description:
 * project_id      a unique id for this project
 * project_name    the name of the project in a unix suitable format
 * project_title   the title of this project ( a full name )
 * description     the description of this project
 * project_site    a url where more information about this project can be found
 * category_id     the category that this project is in
 * license_id      the id of the license that this project uses
 * stage_id        the stage that this project is in default to
 * member_id       the member who created this project
 * approved        if this project has been approved or not
 *                 null = not reviews false = declined true = accpeted
 * site_group_id   the id of the group this project belongs to
 * date_created    the date the project was created
 * 
 */
CREATE SEQUENCE project_project_id_seq;
CREATE TABLE project
(
    project_id     INT4 NOT NULL DEFAULT nextval('project_project_id_seq'),
    project_name   VARCHAR(32) NOT NULL UNIQUE,
    project_title  VARCHAR(100) NOT NULL UNIQUE,
    description    text,
    project_site   VARCHAR(500),
    category_id    INT4,
    license_id     INT4 NOT NULL REFERENCES license (license_id),
    stage_id       INT4 NOT NULL REFERENCES stage (stage_id) default 0,
    member_id      INT4 NOT NULL REFERENCES member (member_id),
    approved       boolean,
    site_group_id  int4 NOT NULL REFERENCES site_group (group_id),
    date_created   timestamp NOT NULL default now(),
    primary key(project_id)
);

/*
 * Table: role
 *
 * Description:
 * These are the different roles users can have on the site
 *
 * Field Description:
 * role_id              the id of this role
 * role_name            the name of this role
 */
CREATE SEQUENCE role_role_id_seq;
CREATE TABLE role
(
    role_id             INT4 NOT NULL DEFAULT nextval('role_role_id_seq'),
    role_name           VARCHAR(50),
    primary key (role_id)
);

/*
 * Table: member_role
 *
 * Description:
 * This table relates different members to a role on projects.
 *
 * Field Description:
 * member_id            the member this role affects
 * role_id              the role this member has
 * project_id           the project this member has this role on
 *
 * Foreign Keys:
 * member_id references member.member_id on delete cascade
 * role_id references role.role_id
 * project_id references project.project_id
 */
CREATE TABLE member_role
(
    member_id           INT4 NOT NULL REFERENCES member (member_id)
                            ON DELETE CASCADE,
    role_id             INT4 NOT NULL REFERENCES role (role_id),
    project_id          INT4 NOT NULL REFERENCES project (project_id),
    primary key (member_id, project_id)
);

/*
 * Table: project_category
 *
 * Description: the category(s) that a project is part of for browse
 *
 * Field Description:
 * project_id     the project in this category
 * cat_id         the id of the cateogry this project is in
 *
 * Primary key: joined project_id and cat_id
 */
create table project_category (
    project_id    int4 not null references project(project_id),
    cat_id        int4 not null references category(cat_id),
    primary key (project_id,cat_id)
);

/*
 * Table: project_join
 *
 * Description: this table is used for members requesting to joing a
 *              project.
 *
 * Field Description:
 * project_id      the project wanting to be joined
 * member_id       the member wanting join the project
 * email           the email address of the member wanting to join
 * message         a message of why the member want to join
 * submit_date     the date the request was made
 * status          status of acceptance for joining
 *
 * Primary key: joined on project_id and member_id
 */
create table project_join (
    project_id     int4 not null references project(project_id),
    member_id      int4 not null references member(member_id),
    email          varchar(50),
    message        text,
    submit_date    date not null default now(),
    status         bool default 'f',
    primary key(project_id, member_id)
);

/*
 * Table: project_news
 *
 * Description: News items about a project
 *
 * Field Description:
 * news_id        the id of this news item (primary key)
 * project_id     the project this news is part of
 * member_id      the member who created this news item
 * temp_id        used to make sure double clicks don't cause problems
 * headline       the news headline
 * body           the body of the of the news
 * submit_date    the date this news item was submitted
 * active         if this news item is active or not
 * group_id       the site group id (this is a little redundant but to make
 *                queries simpler we placed it here as well
 * on_homepage    a boolean: true if this item is to be shown on the homepage
 */
create sequence news_news_id_seq;
create table project_news (
    news_id       int4 unique not null default nextval('news_news_id_seq'),
    project_id    int4 not null references project(project_id),
    member_id     int4 not null references member(member_id),
    temp_id       varchar(32),
    headline      varchar(100) not null,
    body          text not null,
    submit_date   date not null default now(),
    active        bool default 't',
    group_id      int4,
    on_homepage   bool default 't',
    primary key (news_id)
);

/*
 * Table: project_version
 *
 * Description: Contains the different version a project has.
 *              This at the moment is used for the errata but it
 *              will be used for other things in the future.
 *
 * Field Description:
 * version_id   the id of this version record (primary key)
 * project_id   the id of the project this version is part of
 * version_code the version code (i.e. 1.0.3b)
 * description  a description of the version
 * created_by   the member who created this version
 * date_created the date/time this record was created
 */
CREATE SEQUENCE project_version_id_seq;
CREATE table project_version (
    version_id int4 not null default nextval('project_version_id_seq'),
    project_id int4 not null references project(project_id),
    version_code varchar(10) not null,
    description text,
    created_by int4 not null references member(member_id),
    date_created timestamp default now(),
    primary key(version_id)
);

/*
 * Table: project_errata
 * 
 * Description: this table is used for errata information. Each entry is
 *              a specific issue that is attached to a project_version entry
 *              and an errata category type.
 *
 * Field Description:
 * errata_id    the id of this errata entry
 * version_id   the id of the project_version this errata is attached to
 * title        a short description of this entry
 * description  a detailed description about this entry
 * cat_id       the category for this errata
 * created_by   the member who created this entry
 * date_created the date/time this entry was created
 */
CREATE SEQUENCE project_errata_id_seq;
CREATE TABLE project_errata (
    errata_id int4 not null default nextval('project_errata_id_seq'),
    version_id int4 not null references project_version(version_id),
    title varchar(128) not null,
    description text,
    cat_id int4 not null references category (cat_id),
    created_by int4 not null references member (member_id),
    date_created timestamp not null default now(),
    primary key(errata_id)
);

