---
-- FILE: sites.sql
--
-- DESCRIPTION:
-- These are the site_info and related tables for the SiteInfo
-- code being done in php for the flexible look/feel
--
-- CHANGE LOG:
-- Chris Ryan <chris@greatbridge.com> 08/25/2000
--     Initial creation of file.
-- Chris Ryan <chris@greatbridge.com> 08/28/2000
--     Changed font.value type from varchar(16) to varchar(64)
--     Added page_header to the page_info table
--     Added table group_info
--     Added trigger to update last_updated field on group_info
--     Added group_id,page_url,link_name and order_number to the page_info
--         table for the group code
--     Added a foreign key on page_info.group_id to group_info.group_id
--     Added a joined index of group_id and order_number on page_info
--     Added an index on group_info.order_number for sorting purposes
-- Chris Ryan <chris@greatbridge.com> 08/31/2000
--     Some general changes to the way groups are handled
--     Removed foreign key on page_info.group_id
--     Added web_page to group_info
--     Added foreign key on group_info(http_host,web_page)
--         to page_info(http_host,web_page)
--     Added is_content field to group_info
-- Chris Ryan <chris@greatbridge.com> 09/20/2000
--     Added the site_group table
--     Added the group_id field to site_info 
-- Chris Ryan <chris@greatbridge.com> 09/22/2000
--     Added an active field to page_info
--     Changed all SERIAL types to INT4's and added the default nextval(...)
--         and manually created the sequences
--     Increased the size of link_name on page_info from 64 to 256
-- Chris Ryan <chris@greatbridge.com> 10/25/2000
--     Changed all the comments from -- to c style comments to match the rest
--         of the files we have commented
-- Chris Ryan <chris@greatbridge.com> 11/30/2000
--     Added the field use_master to the page_info table
-- Chris Ryan <chris@greatbridge.com> 01/03/2000
--     Changed the Header comment block from c style to sql style comments
--         The reason for this change is because the pgsql parser was not
--         properly parsing the sql file. I don't know what the exact cause was
--         but making this change corrected the problem.
--/

/*
 * FUNCTION: trigger_last_updated
 *
 * DESCRIPTION:
 * This is a function called by the table triggers to update the last_updated
 * field on insert and updates.
 */
create function trigger_last_updated()
    returns opaque
    as 'begin        
            new.last_updated := now();
            return new;
        end;'
    language 'plpgsql';

/*
 * TABLE: site_group
 *
 * DESCRIPTION:
 * This table is a means for us to group different sites together and allows
 * those different sites to use the same service data and or segregate that
 * data on different sites.
 *
 * FIELD DESCRIPTION:
 * group_id       the id of this group
 * description    the description of this group
 *
 * CONSTRAINTS:
 * primary key    the group_id is a primary key
 */
create sequence site_group_group_id_seq;
create table site_group (
    group_id      int4   not null  default nextval('site_group_group_id_seq'),
    description   text   not null,
    primary key(group_id)
);
/* insert the catch all site_group. */
insert into site_group (group_id, description) values (0,'Catch all Group: this group specifies items as belonging to all sites');

/*
 * TABLE: site_info
 *
 * DESCRIPTION:
 * This table contains all the info about a site so that the business
 * logic of the code can look up the UI interface based on the site_info
 * table
 *
 * FIELD DESCRIPTIONS:
 * http_host      is the domain for the site i.e. www.greatbridge.com
 * name_prefix    is a word that all templates have prepended to their name for
 *                this site
 * official_name  this is the official name of the site that can be displayed
 * template_path  used in loading templates so each site can have it's own path
 *                if left blank or null then the defaults for php are used.
 * image_path     the path to images. can be null or blank for relative images
 *                or contain a relative site path such as /images or a full
 *                path with a domain name without the http:// or http:// i.e.
 *                images.greatbridge.com/images Should not end in /
 * group_id       the group_id is the group that this site belongs to. This
 *                field is for the service data that belongs to a site and still
 *                allow us to use different sites for the same site to provide
 *                dynamic look 'n' feel's to users.
 * default_page   specifies if this is a default page, If no matching site is
 *                site_info record is found the first record with default_page
 *                set to true is used. While it is possible to have multiple
 *                records with default_page set to true it is not advised.
 * last_updated   the last time this record was updated for any reason.
 * 
 * CONSTRAINTS:
 * primary key    http_host is the primary key and is used as a foreign key
 *                on the other tables as they all relate to the site_info
 * foreign key    group_id references the site_group table
 */
create table site_info (
    http_host        varchar(128)    not null,
    name_prefix      varchar(16)     not null,
    official_name    varchar(128)    not null,
    template_path    varchar(128),
    image_path       varchar(256),
    group_id         int4            not null default 0,
    default_page     boolean         not null default false,
    last_updated     timestamp       not null default 'now',
    primary key(http_host)
);

/*
 * TABLE: page_info
 *
 * DESCRIPTION:
 * Contains the information about the pages on the site including title,
 * nav_template and other information specific to a page.
 *
 * FIELD DESCRIPTIONS:
 * http_host        the host name of the site i.e. www.greatbridge.com
 *                  foreign key to site_info
 * web_page         the name of the page without the extension i.e. "AboutPage"
 * use_master       a boolean field to specify the use of the master templates or not
 * page_title       the title of the page as displayable text
 * page_template    the name of the page template (the nav_template file)
 * page_header      Some text that can be used to display at the top of a
 *                  page (i.e. a welcome message or other message)
 * meta_description any text to be placed within a meta-description tag
 * meta_keyword     any keywords to be placed within a meta-keyword tag
 * -- the next fields are for the new group information
 * group_id         the id of the group that this page belongs to
 *                  by default all pages belong to "default"
 * page_url         the url to the page (used for navigation and sitemap)
 * link_name        a displayable string to show in navigation and sitemap
 * order_number     a field used to make sorting easier and more predictable
 * -- end the group information fields
 * active           defines if a page is active or not. if not don't show it
 * last_updated     the last time this record was updated for any reason
 *
 * CONSTRAINTS:
 * primary key      http_host and web_page form the primary key for this record
 * foreign key      http_host is a foreign key to site_info.http_host as the
 *                  records are directly related by these values.
 */
create table page_info (
    http_host        varchar(128)    not null,
    web_page         varchar(64)     not null,
    use_master       boolean         not null default true,
    page_title       varchar(128)    not null,
    page_template    varchar(128)    not null,
    page_header      varchar(256),
    meta_description text,
    meta_keyword     text,
    /* new fields for the group information */
    group_id         varchar(16),
    page_url         varchar(256)    not null,
    link_name        varchar(256)    not null,
    order_number     int4            not null default 1,
    /* end the group fields */
    active           boolean	     not null default true,
    last_updated     timestamp       not null default 'now',
    primary key(http_host, web_page),
    foreign key(http_host) 
        references site_info(http_host)
        on update cascade
        deferrable
);
/* This index is on group_id and order_number as the pages will be looked
 * up where all group_id equal a value and sorted by the order_number */
create index group_order_page_info_idx on page_info (group_id, order_number);

/*
 * TABLE: group_info
 *
 * DESCRIPTION:
 * Contains information about the groups created on this site. There should
 * always be a "default" group created with every site.
 *
 * FIELD DESCRIPTIONS:
 * http_host       the host name of the site i.e. www.greatbridge.com
 *                 foreign key to site_info
 * group_id        the id of this group. A name with not special characters
 *                 or spaces.
 * web_page        the page that this group is attached to
 * name            a displayable text string as a name for this group
 * description     a description of this group
 * is_content      true/false if this is a content group. Content groups show
 *                 their children in the navigation while (false)procedureal
 *                 groups don't
 * order_number    a field used to help sort the groups in a predictable manner
 * last_updated    the last time this record was upated
 *
 * CONTRAINTS:
 * primary key     http_host and group_id form the primary key for this record
 * foreign key     http_host is a foreign key to site_info.http_host as the
 *                 records are directly related
 * foreign key     http_host and web_page for a relation to a matching record
 *                 on the page_info table
 */
create table group_info (
    http_host       varchar(128)     not null,
    group_id        varchar(16)      not null,
    web_page        varchar(64)      not null,
    name            varchar(64)      not null,
    description     text,
    is_content      boolean          not null default true,
    order_number    int4             not null default 1,
    last_updated    timestamp        not null default 'now',
    primary key(http_host, group_id),
    foreign key(http_host)
        references site_info(http_host)
        on update cascade
        deferrable,
    foreign key(http_host, web_page)
        references page_info(http_host, web_page)
        on update cascade
        deferrable
);
/* this index is used for the sorting of the groups during a sitemap */
create index order_number_group_info on group_info (order_number);

/*
 * TABLE: color
 *
 * DESCRIPTION:
 * Contains color information for the related site.
 *
 * FIELD DESCRIPTION:
 * http_host        the host name of the site i.e. www.greatbridge.com
 *                  foreign key to site_info
 * number           the color number for this http_host
 * value            the value of this color
 * last_updated     the last time this record was updated
 *
 * CONSTRAINTS:
 * primary key      http_host and number form the primary key for this record
 * foreign key      http_host is a foreign key to site_info.http_host as the
 *                  records are directly related by these values.
 */
create table color (
    http_host       varchar(128)    not null,
    number          int4            not null,
    value           varchar(16)     not null,
    last_updated    timestamp       not null default 'now',
    primary key(http_host, number),
    foreign key(http_host) 
        references site_info(http_host)
        on update cascade
        deferrable
);

/*
 * TABLE: font
 *
 * DESCRIPTION:
 * Contains font information related to a site.
 *
 * FIELD DESCRIPTION:
 * http_host        the host name of the site i.e. www.greatbridge.com
 *                  foreign key to site_info
 * number           the color number for this http_host
 * value            the value of this color
 * last_updated     the last time this record was updated
 *
 * CONSTRAINTS:
 * primary key      http_host and number form the primary key for this record
 * foreign key      http_host is a foreign key to site_info.http_host as the
 *                  records are directly related by these values.
 */
create table font (
    http_host       varchar(128)    not null,
    number          int4            not null,
    value           varchar(64)     not null,
    last_updated    timestamp       not null default 'now',
    primary key(http_host, number),
    foreign key(http_host) 
        references site_info(http_host)
        on update cascade
        deferrable
);

/*
 * TRIGGER: trigger_insert_update_<table>
 *
 * DESCRIPTION:
 * These are the triggers called on insert and updates of all the tables that
 * have the last_updated field. It will use the function trigger_last_updated
 */
create trigger trigger_insert_update_site_info
    before insert or update on site_info
    for each row execute procedure trigger_last_updated();
create trigger trigger_insert_update_group_info
    before insert or update on group_info
    for each row execute procedure trigger_last_updated();
create trigger trigger_insert_update_page_info
    before insert or update on page_info
    for each row execute procedure trigger_last_updated();
create trigger trigger_insert_update_color
    before insert or update on color
    for each row execute procedure trigger_last_updated();
create trigger trigger_insert_update_font
    before insert or update on font
    for each row execute procedure trigger_last_updated();

